..
  SPDX-FileCopyrightText: 2025 Ilya Egorov <0x42005e1f@gmail.com>
  SPDX-License-Identifier: CC-BY-4.0

Installation
============

.. include:: ../README.rst
  :start-after: .. installation-start-marker
  :end-before: .. installation-end-marker

Third-party distributions
-------------------------

Various third-parties provide culsans for their environments.

piwheels
^^^^^^^^

culsans is also available via the `piwheels <https://www.piwheels.org/project/
culsans/>`__, a Python package repository which provides pre-compiled packages
for the Raspberry Pi. Installation is similar to that from PyPI, but you will
need to change your pip configuration or explicitly specify the required index
according to the `FAQ <https://www.piwheels.org/faq.html>`__.
